@@ -35,21 +35,21 @@
 bal.tab.Match <-      function(x, formula = NULL, data = NULL, treat = NULL, covs = NULL,
                                stats, int = FALSE, poly = 1, distance = NULL, addl = NULL, continuous, binary, s.d.denom, thresholds = NULL, weights = NULL, cluster = NULL, imp = NULL, pairwise = TRUE, s.weights = NULL, abs = FALSE, subset = NULL, quick = TRUE,
                                ...) {
-    
-    tryCatch(args <- c(as.list(environment()), list(...))[-1], error = function(e) .err(conditionMessage(e)))
-    
-    #Adjustments to arguments
-    
-    args[vapply(args, rlang::is_missing, logical(1L))] <- NULL
-    args[vapply(args, is_null, logical(1L)) & names(args) %nin% names(match.call())[-1]] <- NULL
-    
-    #Initializing variables
-    X <- do.call("x2base", c(list(x), args), quote = TRUE) 
-    
-    args[names(args) %in% names(X)] <- NULL
-    
-    X <- .assign_X_class(X)
-    
-    do.call("base.bal.tab", c(list(X), args),
-            quote = TRUE)
+  
+  args <- try_chk(c(as.list(environment()), list(...))[-1L])
+  
+  #Adjustments to arguments
+  
+  args[vapply(args, rlang::is_missing, logical(1L))] <- NULL
+  args[lengths(args) == 0L & names(args) %nin% names(match.call())[-1L]] <- NULL
+  
+  #Initializing variables
+  X <- do.call("x2base", c(list(x), args), quote = TRUE) 
+  
+  args[names(X)] <- NULL
+  
+  X <- .assign_X_class(X)
+  
+  do.call("base.bal.tab", c(list(X), args),
+          quote = TRUE)
 }
